﻿using PolyColumn.Connector;
using PolyColumn.DataModels;
using PolyColumn.DataModels.Concrete;
using PolyColumn.DataModels.Loads;
using PolyColumn.DataModels.Results;
using PolyColumn.DataModels.Supports;

// Add supports
List<Support> supports = new List<Support>();
supports.Add(new Support()
{
    Location = 0,
    DisplacementX = new SupportCondition() { Type = SupportConditionType.Fixed },
    DisplacementY = new SupportCondition() { Type = SupportConditionType.Fixed },
    DisplacementZ = new SupportCondition() { Type = SupportConditionType.Fixed },
    RotationX = new SupportCondition() { Type = SupportConditionType.Fixed },
});
supports.Add(new Support()
{
    Location = 5,
    DisplacementY = new SupportCondition() { Type = SupportConditionType.Fixed },
    DisplacementZ = new SupportCondition() { Type = SupportConditionType.Fixed },
    RotationX = new SupportCondition() { Type = SupportConditionType.Fixed },
});

// Add Loads
List<AxialPointLoad> axialPointLoads = new List<AxialPointLoad>();
axialPointLoads.Add(new AxialPointLoad()
{
    Location = 5,
    Load = 200000,
});
List<DistributedLoad> distributedLoads = new List<DistributedLoad>();
distributedLoads.Add(new DistributedLoad()
{
    StartLocation = 0,
    EndLocation = 5,
    StartLoadZ = 10000,
    EndLoadZ = 10000,
});

List<LoadCase> loadCases = new List<LoadCase>();
loadCases.Add(new LoadCase()
{
    Name = "Load Case 1",
    IncludeSelfWeight = true,
    AxialPointLoads = axialPointLoads,
    DistributedLoads = distributedLoads,
});

// Add Cross Section
RectangularConcreteColumnProperties concreteSection = new RectangularConcreteColumnProperties()
{
    Concrete = new ConcreteMaterial() { Name = "C12", AggregateSize = 0.032 },
    LongitudinalReinforcement = new ReinforcementMaterial() { Name = "Y" },
    Depth = 0.4,
    Width = 0.4,
    Cover = 0.03,
    CornerRebarDiameter = 0.012,
    Stirrups = new Stirrups() { Diameter = 0.01, Spacing = 0.1 },
};

PolyColumnDataModel polyColumnDataModel = new PolyColumnDataModel()
{
    FireSettings = null,
    LoadGroups = null,
    LoadCases = loadCases,
    Supports = supports,
    ULSLoadCombinations = null,
    SLSLoadCombinations = null,
    FireLoadCombinations = null,
    ColumnProperties = new ColumnProperties() { ColumnType = ColumnType.RectangularConcreteColumn, RectangularConcreteColumnProperties = concreteSection },
    DesignSettings = null,
    BucklingSettings = null,
    DocumentationSettings = null
};

// Do Calculation
using (var polyColumn = new PolyColumnConnection())
{
    PolyColumnDataModelResult? polyColumnDataModelResult = polyColumn.Calculate(polyColumnDataModel);
    if (polyColumnDataModelResult?.ULSUtilization != null) Console.WriteLine($"ULS utilization: {polyColumnDataModelResult.ULSUtilization}");
    else Console.WriteLine("Calculation failed.");

    polyColumn?.CloseApplication();
}

// Save to file 
string userProfile = Environment.GetFolderPath(Environment.SpecialFolder.UserProfile);
string downloadsPath = Path.Combine(userProfile, "Downloads");
string filePath = Path.Combine(downloadsPath, "Example1 - SimpleConcreteColumn.pco");

Console.WriteLine($"File will be saved to save file to {filePath}");

FileAccessService.SaveModelToFile(polyColumnDataModel, filePath);

Console.WriteLine("Press any key to exit.");
Console.ReadKey();