﻿using PolyColumn.Connector;
using PolyColumn.DataModels;

Console.WriteLine("All .pco files within the directory path will be calculated and saved as pdf");
Console.WriteLine("Please enter a directory path:");

string? directoryPath = Console.ReadLine();

if (!Directory.Exists(directoryPath))
{
    Console.WriteLine("The directory does not exist. Press any key to exit.");
    Console.ReadKey();
    return;
}

string[] pcoFiles = Directory.GetFiles(directoryPath, "*.pco");
// If no files are found, inform the user.
if (pcoFiles.Length == 0)
{
    Console.WriteLine("No .pco files found in the directory.");
    Console.WriteLine("The directory does not exist. Press any key to exit.");
    Console.ReadKey();
    return;
}
else
{
    using (var polyColumn = new PolyColumnConnection())
    {
        foreach (var pcoFile in pcoFiles)
        {
            string pdfFileName = Path.ChangeExtension(pcoFile, ".pdf");
            PolyColumnDataModel? polyColumnDataModel = FileAccessService.LoadModelFromFile(pcoFile);

            try
            {
                bool success = polyColumn.SavePDF(polyColumnDataModel, pdfFileName);
                if (success == true)
                {
                    Console.WriteLine($"PDF file has been saved. {pdfFileName}");
                    continue;
                }
            }
            catch (Exception)
            {
                Console.WriteLine($"PDF file has not been saved. {pdfFileName}");
            }
        }

        polyColumn?.CloseApplication();
    }

    Console.WriteLine("Press any key to exit.");
    Console.ReadKey();
}
